==> xfsdump_2.0.1-2.tar.gz: xfsdump-2.0.1/librmt/rmtmsg.c <==
/*
 * Copyright (c) 2000 Silicon Graphics, Inc.; provided copyright in
 * certain portions may be held by third parties as indicated herein.
 * All Rights Reserved.
 *
 * The code in this source file represents an aggregation of work from
 * Georgia Tech, Fred Fish, Jeff Lee, Arnold Robbins and other Silicon
 * Graphics engineers over the period 1985-2000.
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of version 2 of the GNU General Public License as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it would be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * Further, this software is distributed without any warranty that it is
 * free of the rightful claim of any third person regarding infringement
 * or the like.  Any license provided herein, whether implied or
 * otherwise, applies only to this software file.  Patent licenses, if
 * any, provided herein do not apply to combinations of this program with
 * other software, or any other product whatsoever.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write the Free Software Foundation, Inc., 59
 * Temple Place - Suite 330, Boston MA 02111-1307, USA.
 * 
 * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
 * Mountain View, CA  94043, or:
 * 
 * http://www.sgi.com 
 * 
 * For further information regarding this notice, see: 
 * 
 * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
 */

#include "rmtlib.h"

/*
 * Provide functions for warning and debug messages.
 */

static int rmt_debug_code = 0;

static void
checkcode(void)
{
    if (rmt_debug_code != RMTWARN && 
	rmt_debug_code != RMTDBG) {
	rmt_debug_code = 0;
    }
}

void
_rmt_turnonmsgsbyenv(void)
{
    char *rmt_debug_str = getenv("RMTDEBUG"); 

    if (rmt_debug_str != NULL) {
        rmt_debug_code = atoi(rmt_debug_str);
	checkcode();
    }
}

void
rmt_turnonmsgs(int code)
{
    rmt_debug_code = code;
    checkcode();
}

int
_rmt_msgson(void)
{
    return rmt_debug_code;
}

#define RMT_MAX_MSG_STR 256

void
_rmt_msg(int level, const char *msg, ...)
{
    static char msg_str[RMT_MAX_MSG_STR];
    va_list     arg;

    if (rmt_debug_code >= level) {
	va_start(arg, msg);
	vsprintf(msg_str, msg, arg);
	va_end(arg);

	fprintf(stderr, "%s%s", level==RMTWARN ? "WARNING: ":"", msg_str);
    }
}

==> xfsdump_2.2.27-1.tar.gz: xfsdump-2.2.27/librmt/rmtmsg.c <==
/*
 * Copyright (c) 2000-2001 Silicon Graphics, Inc.; provided copyright in
 * certain portions may be held by third parties as indicated herein.
 * All Rights Reserved.
 *
 * The code in this source file represents an aggregation of work from
 * Georgia Tech, Fred Fish, Jeff Lee, Arnold Robbins and other Silicon
 * Graphics engineers over the period 1985-2000.
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of version 2 of the GNU General Public License as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it would be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * Further, this software is distributed without any warranty that it is
 * free of the rightful claim of any third person regarding infringement
 * or the like.  Any license provided herein, whether implied or
 * otherwise, applies only to this software file.  Patent licenses, if
 * any, provided herein do not apply to combinations of this program with
 * other software, or any other product whatsoever.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write the Free Software Foundation, Inc., 59
 * Temple Place - Suite 330, Boston MA 02111-1307, USA.
 * 
 * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
 * Mountain View, CA  94043, or:
 * 
 * http://www.sgi.com 
 * 
 * For further information regarding this notice, see: 
 * 
 * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
 */

#include "rmtlib.h"

/*
 * Provide functions for warning and debug messages.
 */

static int rmt_debug_code = 0;

static void
checkcode(void)
{
    if (rmt_debug_code != RMTWARN && 
	rmt_debug_code != RMTDBG) {
	rmt_debug_code = 0;
    }
}

void
_rmt_turnonmsgsbyenv(void)
{
    char *rmt_debug_str = getenv("RMTDEBUG"); 

    if (rmt_debug_str != NULL) {
        rmt_debug_code = atoi(rmt_debug_str);
	checkcode();
    }
}

void
rmt_turnonmsgs(int code)
{
    rmt_debug_code = code;
    checkcode();
}

int
_rmt_msgson(void)
{
    return rmt_debug_code;
}

#define RMT_MAX_MSG_STR 256

void
_rmt_msg(int level, const char *msg, ...)
{
    static char msg_str[RMT_MAX_MSG_STR];
    va_list     arg;

    if (rmt_debug_code >= level) {
	va_start(arg, msg);
	vsprintf(msg_str, msg, arg);
	va_end(arg);

	fprintf(stderr, "%s%s", level==RMTWARN ? _("WARNING: "):"", msg_str);
    }
}
